/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package fr.paris.lutece.plugins.stock.business;

import fr.paris.lutece.util.jpa.IGenericHome;

import org.springframework.transaction.annotation.Transactional;

import java.util.List;


/**
 * ICategoryHome the category home interface
 */
public interface ICategoryHome extends IGenericHome<Integer, Category>
{
    /**
     * Finds all categories (first level) and fetch children
     * @return all first level categories
     */
    @Transactional( readOnly = true )
    List<Category> findAllFirstLevelWithChildren(  );

    /**
     * Finds all category's children and fetch children
     * @param idCategory the id of upper category
     * @return all category's children
     */
    @Transactional( readOnly = true )
    List<Category> findAllChildrenWithChildren( Integer idCategory );

    /**
     * Finds a category and all his subcategories  and fetch children
     * @param nIdCategory the id of upper category
     * @return the category
     */
    @Transactional( readOnly = true )
    Category findByPrimarykeyWithChildren( Integer nIdCategory );

    /**
     * Finds a category and fetch parent
     * @param nIdCategory the id of the searched category
     * @return the category
     */
    @Transactional( readOnly = true )
    Category findByIdWithParent( Integer nIdCategory );

    /**
     * Finds a category and fetch product
     * @param nIdCategory the id of the searched category
     * @return the category
     */
    @Transactional( readOnly = true )
    Category findByIdWithProduct( Integer nIdCategory );

    /**
     * Finds by filter and fetch children
     * @param filter the filter
     * @return the category list
     */
    @Transactional( readOnly = true )
    List<Category> findByFilterWithChildren( CategoryFilter filter );

    /**
     * Finds by filter
     * @param filter the filter
     * @return the category list
     */
    @Transactional( readOnly = true )
    List<Category> findByFilter( CategoryFilter filter );
}
