/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.business;


/**
 *
 * ProductFilter
 *
 */
public class ProductFilter implements ISortableFilter
{
    private Integer _idProduct;
    private Float _price;
    private Integer _stockQuantity;
    private Integer _idCategory;
    private boolean _bOrderAsc;
    private String _strOrder;

    /**
     * Return the category id
     * @return the category id
     */
    public Integer getIdCategory(  )
    {
        return _idCategory;
    }

    /**
     * Set the category id
     * @param idCategory the category id
     */
    public void setIdCategory( Integer idCategory )
    {
        _idCategory = idCategory;
    }

    /**
     * Return true if the order is ascending
     * @return true if the order is ascending
     */
    public boolean isOrderAsc(  )
    {
        return _bOrderAsc;
    }

    /**
     * Set the order, true for ascending false for descending
     * @param bOrderAsc the wanted order ( true if the order is ascending )
     */
    public void setOrderAsc( boolean bOrderAsc )
    {
        this._bOrderAsc = bOrderAsc;
    }

    /**
     * Get the colunm for order by
     * @return the column name
     */
    public String getOrder(  )
    {
        return _strOrder;
    }

    /**
     * Set the column to order by
     * @param strOrder the column name
     */
    public void setOrder( String strOrder )
    {
        this._strOrder = strOrder;
    }

    /**
     * Return the product id for filter
     * @return the product id for filter
     */
    public Integer getIdProduct(  )
    {
        return _idProduct;
    }

    /**
     * Set the product id to filter
     * @param idProduct the product id to filter
     */
    public void setIdProduct( Integer idProduct )
    {
        this._idProduct = idProduct;
    }

    /**
     * Return the price to filter
     * @return the price to filter
     */
    public Float getPrice(  )
    {
        return _price;
    }

    /**
     * Set the price to filter
     * @param price the price to filter
     */
    public void setPrice( Float price )
    {
        this._price = price;
    }

    /**
     * Return the stock quantity filtered
     * @return the quantity
     */
    public Integer getStockQuantity(  )
    {
        return _stockQuantity;
    }

    /**
     * Set the quantity to filter
     * @param stockQuantity the quantity filtered
     */
    public void setStockQuantity( Integer stockQuantity )
    {
        this._stockQuantity = stockQuantity;
    }

    /**
     * Return true if there is filters
     * @return boolean
     */
    public boolean hasFilter(  )
    {
        return !( ( _stockQuantity == null ) && ( _strOrder == null ) && ( _idCategory == null ) && ( _price == null ) );
    }
}
