/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.service;

import fr.paris.lutece.plugins.stock.business.ObjectDefinition;
import fr.paris.lutece.plugins.stock.business.Provider;
import fr.paris.lutece.portal.business.user.AdminUser;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;


/**
 *
 * IProviderService
 *
 */
public interface IProviderService
{
    /**
     * Get the creation template of this provider
     * @return the template path
     */
    String getCreateTemplate(  );

    /**
     * Get the modification template of this provider
     * @return the template path
     */
    String getModifyTemplate(  );

    /**
     * Get the class name of this provider object
     * @return the class name
     */
    String getProviderClass(  );

    /**
     * Return the jsp for deleting this provider
     * @return the jsp path
     */
    String getDeleteJsp(  );

    /**
     * Init this service
     */
    void init(  );

    /**
    * Creates a provider
    * @param provider The provider to create in database
    * @param request The HTTP request
    */
    void doCreateProvider( Provider provider, HttpServletRequest request );

    /**
    * Modifies a provider
    * @param provider The provider to modify in database
    * @param request The HTTP request
    */
    void doModifyProvider( Provider provider, HttpServletRequest request );

    /**
    * Delete a provider
    * @param nIdProvider the identifier of the provider to delete
    */
    void doDeleteProvider( int nIdProvider );

    /**
     * Initaliaze the model in parameter for a creation
     * @param model the model wich will be passed in the creation template
     */
    void initModelForCreation( Map<String, Object> model );

    /**
     * Initaliaze the model in parameter for a modification
     * @param nIdProvider the id of the privider to modify
     * @param model the model wich will be passed in the modification template
     */
    void initModelForModification( int nIdProvider, Map<String, Object> model );

    /**
     * Get the specifical ObjectDefinition of the entity object
     * @return the ObjectDefinition of the entity object
     */
    ObjectDefinition getObjectDefinition(  );

    /**
     * Check if the user in parameter can create this type of provider
     * @param user the user who wants to create
     * @return True if the user in parameter is authorized to create a provider. False otherwise.
     */
    boolean isAuthorizedToCreate( AdminUser user );

    /**
     * Check if the user in parameter can modify this type of provider
     * @param user the user who wants to create
     * @return True if the user in parameter is authorized to modify a provider. False otherwise.
     */
    boolean isAuthorizedToModify( AdminUser user );

    /**
     * Check if the user in parameter can delete this type of provider
     * @param user the user who wants to create
     * @return True if the user in parameter is authorized to delete a provider. False otherwise.
     */
    boolean isAuthorizedToDelete( AdminUser user );
}
